//go:build linux
// +build linux

package shell

import (
	"fmt"
	"os"
	"os/exec"
	"syscall"

	"github.com/hpcng/warewulf/internal/pkg/container"
	"github.com/hpcng/warewulf/internal/pkg/wwlog"
	"github.com/spf13/cobra"
)

func CobraRunE(cmd *cobra.Command, args []string) error {

	containerName := args[0]
	var allargs []string

	if !container.ValidSource(containerName) {
		wwlog.Error("Unknown Warewulf container: %s", containerName)
		os.Exit(1)
	}

	for _, b := range binds {
		allargs = append(allargs, "--bind", b)
	}
	allargs = append(allargs, args...)
	allargs = append(allargs, "/usr/bin/bash")

	c := exec.Command("/proc/self/exe", append([]string{"container", "exec"}, allargs...)...)

	//c := exec.Command("/bin/sh")
	c.SysProcAttr = &syscall.SysProcAttr{
		Cloneflags: syscall.CLONE_NEWUTS | syscall.CLONE_NEWPID | syscall.CLONE_NEWNS,
	}
	c.Stdin = os.Stdin
	c.Stdout = os.Stdout
	c.Stderr = os.Stderr

	os.Setenv("WW_CONTAINER_SHELL", containerName)

	if err := c.Run(); err != nil {
		fmt.Println(err)
		os.Exit(1)
	}
	return nil
}
